==> ejc-metadata-api-3.0.0-20200519.075521-34-sources.jar: com/ejianc/foundation/metadata/vo/MdReferVO.java <==
package com.ejianc.foundation.metadata.vo;

import java.io.Serializable;
import java.util.Map;

public class MdReferVO implements Serializable {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	private String projectName;		//工程名称
	
	private Long projectId;			//工程id
	
	private String databaseName; //工程对应数据库名称

	private String entityName; // 实体名称

	private String entityFullName; // 实体全名

	private String tableName; // 表名称
	
	private Map<String,String> refMapList; //参照映射字段

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getDatabaseName() {
		return databaseName;
	}

	public void setDatabaseName(String databaseName) {
		this.databaseName = databaseName;
	}

	public String getEntityName() {
		return entityName;
	}

	public void setEntityName(String entityName) {
		this.entityName = entityName;
	}

	public String getEntityFullName() {
		return entityFullName;
	}

	public void setEntityFullName(String entityFullName) {
		this.entityFullName = entityFullName;
	}

	public String getTableName() {
		return tableName;
	}

	public void setTableName(String tableName) {
		this.tableName = tableName;
	}

	public Map<String,String> getRefMapList() {
		return refMapList;
	}

	public void setRefMapList(Map<String,String> refMapList) {
		this.refMapList = refMapList;
	}
	
	
}

==> ejc-metadata-api-3.0.0-20200722.011959-64-sources.jar: com/ejianc/foundation/metadata/vo/MdReferVO.java <==
package com.ejianc.foundation.metadata.vo;

import java.io.Serializable;
import java.util.Map;

public class MdReferVO implements Serializable {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	private String projectName;		//工程名称
	
	private String projectDisplayName;		//工程名称
	
	private Long projectId;			//工程id
	
	private String databaseName; //工程对应数据库名称

	private String entityName; // 实体名称

	private String entityDisplayName; // 实体名称

	private String entityFullName; // 实体全名

	private String tableName; // 表名称
	
	private Map<String,String> refMapList; //参照映射字段

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getDatabaseName() {
		return databaseName;
	}

	public void setDatabaseName(String databaseName) {
		this.databaseName = databaseName;
	}

	public String getEntityName() {
		return entityName;
	}

	public void setEntityName(String entityName) {
		this.entityName = entityName;
	}

	public String getEntityFullName() {
		return entityFullName;
	}

	public void setEntityFullName(String entityFullName) {
		this.entityFullName = entityFullName;
	}

	public String getTableName() {
		return tableName;
	}

	public void setTableName(String tableName) {
		this.tableName = tableName;
	}

	public Map<String,String> getRefMapList() {
		return refMapList;
	}

	public void setRefMapList(Map<String,String> refMapList) {
		this.refMapList = refMapList;
	}

	public String getProjectDisplayName() {
		return projectDisplayName;
	}

	public void setProjectDisplayName(String projectDisplayName) {
		this.projectDisplayName = projectDisplayName;
	}

	public String getEntityDisplayName() {
		return entityDisplayName;
	}

	public void setEntityDisplayName(String entityDisplayName) {
		this.entityDisplayName = entityDisplayName;
	}
	
	
}
